# Treasure Hunt Next Clue

This package is only for people participating in a treasure hunt conducted by a college club.

## Usage
```python
from PILTH import gimmeLinkAndCode

gimmeLinkAndCode()
```
